from collections import defaultdict
from skidl import Pin, Part, Alias, SchLib, SKIDL, TEMPLATE

from skidl.pin import pin_types

SKIDL_lib_version = '0.0.1'

Sensor_Proximity = SchLib(tool=SKIDL).add_parts(*[
        Part(**{ 'name':'AD7150BRMZ', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AD7150BRMZ'}), 'ref_prefix':'U', 'fplist':['Package_SO:MSOP-10_3x3mm_P0.5mm'], 'footprint':'Package_SO:MSOP-10_3x3mm_P0.5mm', 'keywords':'Analog ADI CDC dual', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/AD7150.pdf', 'search_text':'/usr/share/kicad/symbols/Sensor_Proximity.kicad_sym\nAD7150BRMZ\n\nAnalog ADI CDC dual', 'pins':[
            Pin(num='1',name='GND',func=pin_types.PWRIN),
            Pin(num='10',name='SDA',func=pin_types.BIDIR),
            Pin(num='2',name='VDD',func=pin_types.PWRIN),
            Pin(num='3',name='CIN2',func=pin_types.PASSIVE),
            Pin(num='4',name='CIN1',func=pin_types.PASSIVE),
            Pin(num='5',name='EXC2',func=pin_types.OUTPUT),
            Pin(num='6',name='EXC1',func=pin_types.OUTPUT),
            Pin(num='7',name='OUT1',func=pin_types.OUTPUT),
            Pin(num='8',name='OUT2',func=pin_types.OUTPUT),
            Pin(num='9',name='SCL',func=pin_types.INPUT)], 'unit_defs':[] }),
        Part(**{ 'name':'AD7151BRMZ', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AD7151BRMZ'}), 'ref_prefix':'U', 'fplist':['Package_SO:MSOP-10_3x3mm_P0.5mm'], 'footprint':'Package_SO:MSOP-10_3x3mm_P0.5mm', 'keywords':'Analog ADI CDC single', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/AD7151.pdf', 'search_text':'/usr/share/kicad/symbols/Sensor_Proximity.kicad_sym\nAD7151BRMZ\n\nAnalog ADI CDC single', 'pins':[
            Pin(num='1',name='GND',func=pin_types.PWRIN),
            Pin(num='10',name='SDA',func=pin_types.BIDIR),
            Pin(num='2',name='VDD',func=pin_types.PWRIN),
            Pin(num='9',name='SCL',func=pin_types.INPUT),
            Pin(num='3',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='4',name='CIN',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='6',name='EXC',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='OUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'APDS-9160-003', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'APDS-9160-003'}), 'ref_prefix':'U', 'fplist':['OptoDevice:Broadcom_APDS-9160-003'], 'footprint':'OptoDevice:Broadcom_APDS-9160-003', 'keywords':'opto proximity sensor avago broadcom', 'description':'', 'datasheet':'https://docs.broadcom.com/docs/APDS-9160-003-DS', 'search_text':'/usr/share/kicad/symbols/Sensor_Proximity.kicad_sym\nAPDS-9160-003\n\nopto proximity sensor avago broadcom', 'pins':[
            Pin(num='1',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='INT',func=pin_types.OPENCOLL,unit=1),
            Pin(num='3',name='LDR',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='LEDK',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='LEDA',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='SCL',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'BPR-205', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'BPR-205'}), 'ref_prefix':'U', 'fplist':['OptoDevice:Everlight_ITR8307'], 'footprint':'OptoDevice:Everlight_ITR8307', 'keywords':'Reflective Optical Sensor Opto', 'description':'', 'datasheet':'http://www.ystone.com.tw/en/data/goods/IRPT/Photo%20Interrupters-Reflective%20Type.pdf', 'search_text':'/usr/share/kicad/symbols/Sensor_Proximity.kicad_sym\nBPR-205\n\nReflective Optical Sensor Opto', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='C',func=pin_types.OPENCOLL,unit=1),
            Pin(num='4',name='E',func=pin_types.OPENEMIT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'CNY70', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'CNY70'}), 'ref_prefix':'U', 'fplist':['OptoDevice:Vishay_CNY70'], 'footprint':'OptoDevice:Vishay_CNY70', 'keywords':'Reflective Optical Sensor Opto', 'description':'', 'datasheet':'https://www.vishay.com/docs/83751/cny70.pdf', 'search_text':'/usr/share/kicad/symbols/Sensor_Proximity.kicad_sym\nCNY70\n\nReflective Optical Sensor Opto', 'pins':[
            Pin(num='1',name='A',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='C',func=pin_types.OPENCOLL,unit=1),
            Pin(num='4',name='E',func=pin_types.OPENEMIT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'GP2S700HCP', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'GP2S700HCP'}), 'ref_prefix':'U', 'fplist':['OptoDevice:Sharp_GP2S700HCP'], 'footprint':'OptoDevice:Sharp_GP2S700HCP', 'keywords':'Reflective Optical Sensor Opto reflex coupler', 'description':'', 'datasheet':'https://www.sharpsde.com/fileadmin/products/Optoelectronics/Isolation%20Devices/Specs_Photointerrupter/GP2S700HCP_03Oct05_DS_D3-A02201FEN.pdf', 'search_text':'/usr/share/kicad/symbols/Sensor_Proximity.kicad_sym\nGP2S700HCP\n\nReflective Optical Sensor Opto reflex coupler', 'pins':[
            Pin(num='1',name='~',func=pin_types.OPENEMIT,unit=1),
            Pin(num='2',name='~',func=pin_types.OPENCOLL,unit=1),
            Pin(num='3',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ITR1201SR10AR', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ITR1201SR10AR'}), 'ref_prefix':'U', 'fplist':['OptoDevice:Everlight_ITR1201SR10AR'], 'footprint':'OptoDevice:Everlight_ITR1201SR10AR', 'keywords':'Reflective Optical Sensor Opto reflex coupler', 'description':'', 'datasheet':'http://www.everlight.com/file/ProductFile/ITR1201SR10AR-TR.pdf', 'search_text':'/usr/share/kicad/symbols/Sensor_Proximity.kicad_sym\nITR1201SR10AR\n\nReflective Optical Sensor Opto reflex coupler', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.OPENCOLL,unit=1),
            Pin(num='4',name='~',func=pin_types.OPENEMIT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ITR8307', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ITR8307'}), 'ref_prefix':'U', 'fplist':['OptoDevice:Everlight_ITR8307'], 'footprint':'OptoDevice:Everlight_ITR8307', 'keywords':'Reflective Optical Sensor Opto', 'description':'', 'datasheet':'http://www.everlight.com/file/ProductFile/ITR8307.pdf', 'search_text':'/usr/share/kicad/symbols/Sensor_Proximity.kicad_sym\nITR8307\n\nReflective Optical Sensor Opto', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='C',func=pin_types.OPENCOLL,unit=1),
            Pin(num='4',name='E',func=pin_types.OPENEMIT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ITR8307-F43', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ITR8307-F43'}), 'ref_prefix':'U', 'fplist':['OptoDevice:Everlight_ITR8307F43'], 'footprint':'OptoDevice:Everlight_ITR8307F43', 'keywords':'Reflective Optical Sensor Opto', 'description':'', 'datasheet':'https://everlighteurope.com/index.php?controller=attachment&id_attachment=5385', 'search_text':'/usr/share/kicad/symbols/Sensor_Proximity.kicad_sym\nITR8307-F43\n\nReflective Optical Sensor Opto', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='C',func=pin_types.OPENCOLL,unit=1),
            Pin(num='4',name='E',func=pin_types.OPENEMIT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ITR9608-F', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ITR9608-F'}), 'ref_prefix':'U', 'fplist':['OptoDevice:Everlight_ITR9608-F'], 'footprint':'OptoDevice:Everlight_ITR9608-F', 'keywords':'Photointerrupter opto interrupter infrared LED fast response time infrared 940nm 5mm gap', 'description':'', 'datasheet':'https://www.everlighteurope.com/custom/files/datasheets/DRX-0000076.pdf', 'search_text':'/usr/share/kicad/symbols/Sensor_Proximity.kicad_sym\nITR9608-F\n\nPhotointerrupter opto interrupter infrared LED fast response time infrared 940nm 5mm gap', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.OPENCOLL,unit=1),
            Pin(num='4',name='~',func=pin_types.OPENEMIT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'KRC011', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'KRC011'}), 'ref_prefix':'U', 'fplist':['OptoDevice:Kingbright_KRC011_Vertical'], 'footprint':'OptoDevice:Kingbright_KRC011_Vertical', 'keywords':'Reflective Optical Sensor Opto', 'description':'', 'datasheet':'http://www.kingbright.com/attachments/file/psearch/000/00/00/KRC011(Ver.15).pdf', 'search_text':'/usr/share/kicad/symbols/Sensor_Proximity.kicad_sym\nKRC011\n\nReflective Optical Sensor Opto', 'pins':[
            Pin(num='1',name='A',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='C',func=pin_types.OPENCOLL,unit=1),
            Pin(num='4',name='E',func=pin_types.OPENEMIT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LDC1312', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LDC1312'}), 'ref_prefix':'U', 'fplist':['Package_SON:WSON-12-1EP_4x4mm_P0.5mm_EP2.6x3mm_ThermalVias'], 'footprint':'Package_SON:WSON-12-1EP_4x4mm_P0.5mm_EP2.6x3mm_ThermalVias', 'keywords':'inductance sensor', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/ldc1312.pdf', 'search_text':'/usr/share/kicad/symbols/Sensor_Proximity.kicad_sym\nLDC1312\n\ninductance sensor', 'pins':[
            Pin(num='1',name='SCL',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='IN0B',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='IN1A',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='IN1B',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='CLKIN',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='ADDR',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='INTB',func=pin_types.OPENCOLL,unit=1),
            Pin(num='6',name='SD',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='IN0A',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LDC1314', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LDC1314'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:WQFN-16-1EP_4x4mm_P0.5mm_EP2.6x2.6mm_ThermalVias'], 'footprint':'Package_DFN_QFN:WQFN-16-1EP_4x4mm_P0.5mm_EP2.6x2.6mm_ThermalVias', 'keywords':'inductance sensor', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/ldc1312.pdf', 'search_text':'/usr/share/kicad/symbols/Sensor_Proximity.kicad_sym\nLDC1314\n\ninductance sensor', 'pins':[
            Pin(num='1',name='SCL',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='IN0B',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='IN1A',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='IN1B',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='IN2A',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='IN2B',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='IN3A',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='IN3B',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='CLKIN',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='ADDR',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='INTB',func=pin_types.OPENCOLL,unit=1),
            Pin(num='6',name='SD',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='IN0A',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LG206D', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LG206D'}), 'ref_prefix':'U', 'fplist':['OptoDevice:Kodenshi_LG206D'], 'footprint':'OptoDevice:Kodenshi_LG206D', 'keywords':'Photointerrupter infrared LED with photo IC, non-inverting output, -0.5V to 17V VDD, -20 to +85 degree Celsius, LG206D', 'description':'', 'datasheet':'http://kodenshi.co.jp/products/pdf/sensor/photointerrupter_ic/LG206D.pdf', 'search_text':'/usr/share/kicad/symbols/Sensor_Proximity.kicad_sym\nLG206D\n\nPhotointerrupter infrared LED with photo IC, non-inverting output, -0.5V to 17V VDD, -20 to +85 degree Celsius, LG206D', 'pins':[
            Pin(num='1',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='VOUT',func=pin_types.OPENCOLL,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='A',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='K',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LG206L', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LG206L'}), 'ref_prefix':'U', 'fplist':['OptoDevice:Kodenshi_LG206L'], 'footprint':'OptoDevice:Kodenshi_LG206L', 'keywords':'Photointerrupter infrared LED with photo IC, inverting output, -0.5V to 17V VDD, -20 to +85 degree Celsius, LG206X', 'description':'', 'datasheet':'http://kodenshi.co.jp/products/pdf/sensor/photointerrupter_ic/LG206L.pdf', 'search_text':'/usr/share/kicad/symbols/Sensor_Proximity.kicad_sym\nLG206L\n\nPhotointerrupter infrared LED with photo IC, inverting output, -0.5V to 17V VDD, -20 to +85 degree Celsius, LG206X', 'pins':[
            Pin(num='1',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='VOUT',func=pin_types.OPENCOLL,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='A',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='K',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'QRE1113', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'QRE1113'}), 'ref_prefix':'U', 'fplist':['OptoDevice:OnSemi_CASE100AQ'], 'footprint':'OptoDevice:OnSemi_CASE100AQ', 'keywords':'Reflective Optical Sensor Opto reflex coupler', 'description':'', 'datasheet':'http://www.onsemi.com/pub/Collateral/QRE1113-D.PDF', 'search_text':'/usr/share/kicad/symbols/Sensor_Proximity.kicad_sym\nQRE1113\n\nReflective Optical Sensor Opto reflex coupler', 'pins':[
            Pin(num='1',name='A',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.OPENCOLL,unit=1),
            Pin(num='4',name='~',func=pin_types.OPENEMIT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'QRE1113GR', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'QRE1113GR'}), 'ref_prefix':'U', 'fplist':['OptoDevice:OnSemi_CASE100CY'], 'footprint':'OptoDevice:OnSemi_CASE100CY', 'keywords':'Reflective Optical Sensor Opto reflex coupler', 'description':'', 'datasheet':'http://www.onsemi.com/pub/Collateral/QRE1113-D.PDF', 'search_text':'/usr/share/kicad/symbols/Sensor_Proximity.kicad_sym\nQRE1113GR\n\nReflective Optical Sensor Opto reflex coupler', 'pins':[
            Pin(num='1',name='A',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.OPENCOLL,unit=1),
            Pin(num='4',name='~',func=pin_types.OPENEMIT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'RPR-0720', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'RPR-0720'}), 'ref_prefix':'U', 'fplist':['OptoDevice:Rohm_RPR-0720'], 'footprint':'OptoDevice:Rohm_RPR-0720', 'keywords':'opto rohm', 'description':'', 'datasheet':'https://fscdn.rohm.com/en/products/databook/datasheet/opto/optical_sensor/photosensor/rpr-0720-e.pdf', 'search_text':'/usr/share/kicad/symbols/Sensor_Proximity.kicad_sym\nRPR-0720\n\nopto rohm', 'pins':[
            Pin(num='1',name='VCSELA',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='SCL',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='INT',func=pin_types.OPENCOLL,unit=1),
            Pin(num='5',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='GND',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SFH900', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SFH900'}), 'ref_prefix':'U', 'fplist':['OptoDevice:Siemens_SFH900'], 'footprint':'OptoDevice:Siemens_SFH900', 'keywords':'Reflective Optical Sensor Opto', 'description':'', 'datasheet':'https://www.batronix.com/pdf/sfh900.pdf', 'search_text':'/usr/share/kicad/symbols/Sensor_Proximity.kicad_sym\nSFH900\n\nReflective Optical Sensor Opto', 'pins':[
            Pin(num='1',name='A',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='C',func=pin_types.OPENCOLL,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SFH9206', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SFH9206'}), 'ref_prefix':'U', 'fplist':['OptoDevice:Osram_SFH9x0x'], 'footprint':'OptoDevice:Osram_SFH9x0x', 'keywords':'Reflective Opto Interrupter Coupler', 'description':'', 'datasheet':'http://www.osram-os.com/Graphics/XPic6/00200860_0.pdf', 'search_text':'/usr/share/kicad/symbols/Sensor_Proximity.kicad_sym\nSFH9206\n\nReflective Opto Interrupter Coupler', 'pins':[
            Pin(num='1',name='A',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='3',name='E',func=pin_types.OPENEMIT,unit=1),
            Pin(num='4',name='C',func=pin_types.OPENCOLL,unit=1),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='6',name='K',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SG-105', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SG-105'}), 'ref_prefix':'U', 'fplist':['OptoDevice:Kodenshi_SG105'], 'footprint':'OptoDevice:Kodenshi_SG105', 'keywords':'Reflective Optical Sensor Opto', 'description':'', 'datasheet':'http://www.kodenshi.co.jp/products/pdf/sensor/photointerrupter_ref/SG-105.pdf', 'search_text':'/usr/share/kicad/symbols/Sensor_Proximity.kicad_sym\nSG-105\n\nReflective Optical Sensor Opto', 'pins':[
            Pin(num='1',name='A',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='C',func=pin_types.OPENCOLL,unit=1),
            Pin(num='4',name='E',func=pin_types.OPENEMIT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SG-105F', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SG-105F'}), 'ref_prefix':'U', 'fplist':['OptoDevice:Kodenshi_SG105F'], 'footprint':'OptoDevice:Kodenshi_SG105F', 'keywords':'Reflective Optical Sensor Opto', 'description':'', 'datasheet':'http://www.kodenshi.co.jp/products/pdf/sensor/photointerrupter_ref/SG-105F.pdf', 'search_text':'/usr/share/kicad/symbols/Sensor_Proximity.kicad_sym\nSG-105F\n\nReflective Optical Sensor Opto', 'pins':[
            Pin(num='1',name='A',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='C',func=pin_types.OPENCOLL,unit=1),
            Pin(num='4',name='E',func=pin_types.OPENEMIT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TSSP58P38', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TSSP58P38'}), 'ref_prefix':'U', 'fplist':['OptoDevice:Vishay_MINICAST-3Pin'], 'footprint':'OptoDevice:Vishay_MINICAST-3Pin', 'keywords':'opto IR receiver', 'description':'', 'datasheet':'http://www.vishay.com/docs/82462/tsop581.pdf', 'search_text':'/usr/share/kicad/symbols/Sensor_Proximity.kicad_sym\nTSSP58P38\n\nopto IR receiver', 'pins':[
            Pin(num='1',name='OUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='Vs',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'BPR-105', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'BPR-105'}), 'ref_prefix':'U', 'fplist':['OptoDevice:Everlight_ITR8307', 'OptoDevice:Everlight_ITR8307'], 'footprint':'OptoDevice:Everlight_ITR8307', 'keywords':'Reflective Optical Sensor Opto', 'description':'', 'datasheet':'http://www.ystone.com.tw/en/data/goods/IRPT/Photo%20Interrupters-Reflective%20Type.pdf', 'search_text':'/usr/share/kicad/symbols/Sensor_Proximity.kicad_sym\nBPR-105\n\nReflective Optical Sensor Opto', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='C',func=pin_types.OPENCOLL,unit=1),
            Pin(num='4',name='E',func=pin_types.OPENEMIT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'BPR-105F', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'BPR-105F'}), 'ref_prefix':'U', 'fplist':['OptoDevice:Everlight_ITR8307F43', 'OptoDevice:Everlight_ITR8307F43'], 'footprint':'OptoDevice:Everlight_ITR8307F43', 'keywords':'Reflective Optical Sensor Opto', 'description':'', 'datasheet':'http://www.ystone.com.tw/en/data/goods/IRPT/Photo%20Interrupters-Reflective%20Type.pdf', 'search_text':'/usr/share/kicad/symbols/Sensor_Proximity.kicad_sym\nBPR-105F\n\nReflective Optical Sensor Opto', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='C',func=pin_types.OPENCOLL,unit=1),
            Pin(num='4',name='E',func=pin_types.OPENEMIT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ITR8307-L24-TR8', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ITR8307-L24-TR8'}), 'ref_prefix':'U', 'fplist':['OptoDevice:Everlight_ITR1201SR10AR', 'OptoDevice:Everlight_ITR1201SR10AR'], 'footprint':'OptoDevice:Everlight_ITR1201SR10AR', 'keywords':'Reflective Optical Sensor Opto reflex coupler', 'description':'', 'datasheet':'https://www.everlight.com/file/ProductFile/ITR8307-L24-TR8.pdf', 'search_text':'/usr/share/kicad/symbols/Sensor_Proximity.kicad_sym\nITR8307-L24-TR8\n\nReflective Optical Sensor Opto reflex coupler', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.OPENCOLL,unit=1),
            Pin(num='4',name='~',func=pin_types.OPENEMIT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ITR8307-S17-TR8', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ITR8307-S17-TR8'}), 'ref_prefix':'U', 'fplist':['OptoDevice:Everlight_ITR1201SR10AR', 'OptoDevice:Everlight_ITR1201SR10AR', 'OptoDevice:Everlight_ITR1201SR10AR'], 'footprint':'OptoDevice:Everlight_ITR1201SR10AR', 'keywords':'Reflective Optical Sensor Opto reflex coupler', 'description':'', 'datasheet':'https://datasheet.lcsc.com/szlcsc/1810010232_Everlight-Elec-ITR8307-S17-TR8-B_C81632.pdf', 'search_text':'/usr/share/kicad/symbols/Sensor_Proximity.kicad_sym\nITR8307-S17-TR8\n\nReflective Optical Sensor Opto reflex coupler', 'pins':[
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.OPENCOLL,unit=1),
            Pin(num='4',name='~',func=pin_types.OPENEMIT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LDC1612', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LDC1612'}), 'ref_prefix':'U', 'fplist':['Package_SON:WSON-12-1EP_4x4mm_P0.5mm_EP2.6x3mm_ThermalVias', 'Package_SON:WSON-12-1EP_4x4mm_P0.5mm_EP2.6x3mm_ThermalVias'], 'footprint':'Package_SON:WSON-12-1EP_4x4mm_P0.5mm_EP2.6x3mm_ThermalVias', 'keywords':'inductance sensor', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/ldc1612.pdf', 'search_text':'/usr/share/kicad/symbols/Sensor_Proximity.kicad_sym\nLDC1612\n\ninductance sensor', 'pins':[
            Pin(num='1',name='SCL',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='IN0B',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='IN1A',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='IN1B',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='CLKIN',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='ADDR',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='INTB',func=pin_types.OPENCOLL,unit=1),
            Pin(num='6',name='SD',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='IN0A',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LDC1614', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LDC1614'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:WQFN-16-1EP_4x4mm_P0.5mm_EP2.6x2.6mm_ThermalVias', 'Package_DFN_QFN:WQFN-16-1EP_4x4mm_P0.5mm_EP2.6x2.6mm_ThermalVias'], 'footprint':'Package_DFN_QFN:WQFN-16-1EP_4x4mm_P0.5mm_EP2.6x2.6mm_ThermalVias', 'keywords':'inductance sensor', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/ldc1612.pdf', 'search_text':'/usr/share/kicad/symbols/Sensor_Proximity.kicad_sym\nLDC1614\n\ninductance sensor', 'pins':[
            Pin(num='1',name='SCL',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='IN0B',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='IN1A',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='IN1B',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='IN2A',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='IN2B',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='IN3A',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='IN3B',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='CLKIN',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='ADDR',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='INTB',func=pin_types.OPENCOLL,unit=1),
            Pin(num='6',name='SD',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='IN0A',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SFH9201', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SFH9201'}), 'ref_prefix':'U', 'fplist':['OptoDevice:Osram_SFH9x0x', 'OptoDevice:Osram_SFH9x0x'], 'footprint':'OptoDevice:Osram_SFH9x0x', 'keywords':'Reflective Opto Interrupter Coupler', 'description':'', 'datasheet':'https://media.digikey.com/pdf/Data%20Sheets/Osram%20PDFs/SFH_9201.pdf', 'search_text':'/usr/share/kicad/symbols/Sensor_Proximity.kicad_sym\nSFH9201\n\nReflective Opto Interrupter Coupler', 'pins':[
            Pin(num='1',name='A',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='3',name='E',func=pin_types.OPENEMIT,unit=1),
            Pin(num='4',name='C',func=pin_types.OPENCOLL,unit=1),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='6',name='K',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SFH9202', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SFH9202'}), 'ref_prefix':'U', 'fplist':['OptoDevice:Osram_SFH9x0x', 'OptoDevice:Osram_SFH9x0x', 'OptoDevice:Osram_SFH9x0x'], 'footprint':'OptoDevice:Osram_SFH9x0x', 'keywords':'Reflective Opto Interrupter Coupler', 'description':'', 'datasheet':'http://www.osram-os.com/Graphics/XPic0/00083379_0.pdf/SFH%209202,%20Lead%20%28Pb%29%20Free%20Product%20-%20RoHS%20Compliant.pdf', 'search_text':'/usr/share/kicad/symbols/Sensor_Proximity.kicad_sym\nSFH9202\n\nReflective Opto Interrupter Coupler', 'pins':[
            Pin(num='1',name='A',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='3',name='E',func=pin_types.OPENEMIT,unit=1),
            Pin(num='4',name='C',func=pin_types.OPENCOLL,unit=1),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='6',name='K',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SG-107', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SG-107'}), 'ref_prefix':'U', 'fplist':['OptoDevice:Kodenshi_SG105', 'OptoDevice:Kodenshi_SG105'], 'footprint':'OptoDevice:Kodenshi_SG105', 'keywords':'Reflective Optical Sensor Opto', 'description':'', 'datasheet':'http://www.kodenshi.co.jp/products/pdf/sensor/photointerrupter_ref/SG-107.pdf', 'search_text':'/usr/share/kicad/symbols/Sensor_Proximity.kicad_sym\nSG-107\n\nReflective Optical Sensor Opto', 'pins':[
            Pin(num='1',name='A',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='C',func=pin_types.OPENCOLL,unit=1),
            Pin(num='4',name='E',func=pin_types.OPENEMIT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SG-107F', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SG-107F'}), 'ref_prefix':'U', 'fplist':['OptoDevice:Kodenshi_SG105F', 'OptoDevice:Kodenshi_SG105F'], 'footprint':'OptoDevice:Kodenshi_SG105F', 'keywords':'Reflective Optical Sensor Opto', 'description':'', 'datasheet':'https://www.pacer.co.uk/Assets/User/1055-SG-107F.pdf', 'search_text':'/usr/share/kicad/symbols/Sensor_Proximity.kicad_sym\nSG-107F\n\nReflective Optical Sensor Opto', 'pins':[
            Pin(num='1',name='A',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='C',func=pin_types.OPENCOLL,unit=1),
            Pin(num='4',name='E',func=pin_types.OPENEMIT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TSSP58038', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TSSP58038'}), 'ref_prefix':'U', 'fplist':['OptoDevice:Vishay_MINICAST-3Pin', 'OptoDevice:Vishay_MINICAST-3Pin'], 'footprint':'OptoDevice:Vishay_MINICAST-3Pin', 'keywords':'opto IR receiver proximity sensor', 'description':'', 'datasheet':'http://www.vishay.com/docs/82476/tssp58p38.pdf', 'search_text':'/usr/share/kicad/symbols/Sensor_Proximity.kicad_sym\nTSSP58038\n\nopto IR receiver proximity sensor', 'pins':[
            Pin(num='1',name='OUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='Vs',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TSSP58038SS1XB', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TSSP58038SS1XB'}), 'ref_prefix':'U', 'fplist':['OptoDevice:Vishay_MINICAST-3Pin', 'OptoDevice:Vishay_MINICAST-3Pin', 'OptoDevice:Vishay_MINICAST-3Pin'], 'footprint':'OptoDevice:Vishay_MINICAST-3Pin', 'keywords':'opto IR receiver light barrier', 'description':'', 'datasheet':'http://www.vishay.com/docs/82740/tssp58038ss1xb.pdf', 'search_text':'/usr/share/kicad/symbols/Sensor_Proximity.kicad_sym\nTSSP58038SS1XB\n\nopto IR receiver light barrier', 'pins':[
            Pin(num='1',name='OUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='Vs',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] })])


from collections import defaultdict
from skidl import Pin, Part, Alias, SchLib, SKIDL, TEMPLATE

from skidl.pin import pin_types

SKIDL_lib_version = '0.0.1'

MCU_WCH_CH32V2 = SchLib(tool=SKIDL).add_parts(*[
        Part(**{ 'name':'CH32V203CxTx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'CH32V203CxTx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-48_7x7mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-48_7x7mm_P0.5mm', 'keywords':'RISC-V WCH MCU', 'description':'', 'datasheet':'https://www.wch-ic.com/products/CH32V203.html', 'search_text':'/usr/share/kicad/symbols/MCU_WCH_CH32V2.kicad_sym\nCH32V203CxTx\n\nRISC-V WCH MCU', 'pins':[
            Pin(num='1',name='VBAT',func=pin_types.PWRIN),
            Pin(num='23',name='VSS',func=pin_types.PWRIN),
            Pin(num='24',name='VDD_VIO',func=pin_types.PWRIN),
            Pin(num='44',name='BOOT0',func=pin_types.INPUT),
            Pin(num='8',name='VSSA',func=pin_types.PWRIN),
            Pin(num='9',name='VDDA',func=pin_types.PWRIN),
            Pin(num='10',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC13',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PB10',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PB11',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PB12',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB13',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB14',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB15',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PA8',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PC14',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PA10',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='SWDIO',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='37',name='SWCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PC15',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PB9',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='OSC_IN',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='OSC_OUT',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='~{RST}',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'CH32V203F6P6', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'CH32V203F6P6'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-20_4.4x6.5mm_P0.65mm', 'keywords':'RISC-V WCH MCU', 'description':'', 'datasheet':'http://www.wch-ic.com/products/CH32V203.html', 'search_text':'/usr/share/kicad/symbols/MCU_WCH_CH32V2.kicad_sym\nCH32V203F6P6\n\nRISC-V WCH MCU', 'pins':[
            Pin(num='1',name='BOOT0',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='PA11',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PA12',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='SWDIO',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='OSC_IN',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='SWCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='OSC_OUT',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='~{RST}',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'CH32V203GxUx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'CH32V203GxUx'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-28-1EP_4x4mm_P0.4mm_EP2.8x2.8mm'], 'footprint':'Package_DFN_QFN:QFN-28-1EP_4x4mm_P0.4mm_EP2.8x2.8mm', 'keywords':'RISCV WCH MCU', 'description':'', 'datasheet':'https://www.wch-ic.com/downloads/CH32V203DS0_PDF.html', 'search_text':'/usr/share/kicad/symbols/MCU_WCH_CH32V2.kicad_sym\nCH32V203GxUx\n\nRISCV WCH MCU', 'pins':[
            Pin(num='1',name='BOOT0/PB8',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='PA9',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PA10/PA11/USB_D-',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='OSC_IN/PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PA12/USB_D+',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PA13/SWDIO',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PA14/SWCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PA15',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='OSC_OUT/PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='~{RST}',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PA3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] })])


from collections import defaultdict
from skidl import Pin, Part, Alias, SchLib, SKIDL, TEMPLATE

from skidl.pin import pin_types

SKIDL_lib_version = '0.0.1'

Comparator = SchLib(tool=SKIDL).add_parts(*[
        Part(**{ 'name':'AD8561', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AD8561'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'cmp complementary push-pull', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/ad8561.pdf', 'search_text':'/usr/share/kicad/symbols/Comparator.kicad_sym\nAD8561\n\ncmp complementary push-pull', 'pins':[
            Pin(num='1',name='V+',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='+',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='-',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='V-',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='LATCH',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='Q',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='~{Q}',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ADCMP350', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ADCMP350'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:Analog_KS-4'], 'footprint':'Package_TO_SOT_SMD:Analog_KS-4', 'keywords':'cmp collector', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/ADCMP350_354_356.pdf', 'search_text':'/usr/share/kicad/symbols/Comparator.kicad_sym\nADCMP350\n\ncmp collector', 'pins':[
            Pin(num='1',name='VIN',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='~',func=pin_types.OPENCOLL,unit=1),
            Pin(num='4',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ADCMP356', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ADCMP356'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:Analog_KS-4'], 'footprint':'Package_TO_SOT_SMD:Analog_KS-4', 'keywords':'cmp', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/ADCMP350_354_356.pdf', 'search_text':'/usr/share/kicad/symbols/Comparator.kicad_sym\nADCMP356\n\ncmp', 'pins':[
            Pin(num='1',name='VIN',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LM2901', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LM2901'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'cmp open collector', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/lm2901.pdf', 'search_text':'/usr/share/kicad/symbols/Comparator.kicad_sym\nLM2901\n\ncmp open collector', 'pins':[
            Pin(num='2',name='~',func=pin_types.OPENCOLL,unit=1),
            Pin(num='4',name='-',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='+',func=pin_types.INPUT,unit=1),
            Pin(num='1',name='~',func=pin_types.OPENCOLL,unit=2),
            Pin(num='6',name='-',func=pin_types.INPUT,unit=2),
            Pin(num='7',name='+',func=pin_types.INPUT,unit=2),
            Pin(num='10',name='-',func=pin_types.INPUT,unit=3),
            Pin(num='11',name='+',func=pin_types.INPUT,unit=3),
            Pin(num='13',name='~',func=pin_types.OPENCOLL,unit=3),
            Pin(num='14',name='~',func=pin_types.OPENCOLL,unit=4),
            Pin(num='8',name='-',func=pin_types.INPUT,unit=4),
            Pin(num='9',name='+',func=pin_types.INPUT,unit=4),
            Pin(num='12',name='V-',func=pin_types.PWRIN,unit=5),
            Pin(num='3',name='V+',func=pin_types.PWRIN,unit=5)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['2', '5', '4']},{'label': 'uB', 'num': 2, 'pin_nums': ['1', '7', '6']},{'label': 'uC', 'num': 3, 'pin_nums': ['10', '13', '11']},{'label': 'uD', 'num': 4, 'pin_nums': ['8', '9', '14']},{'label': 'uE', 'num': 5, 'pin_nums': ['12', '3']}] }),
        Part(**{ 'name':'LM2903', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LM2903'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'cmp open collector', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/lm393.pdf', 'search_text':'/usr/share/kicad/symbols/Comparator.kicad_sym\nLM2903\n\ncmp open collector', 'pins':[
            Pin(num='1',name='~',func=pin_types.OPENCOLL,unit=1),
            Pin(num='2',name='-',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='+',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='+',func=pin_types.INPUT,unit=2),
            Pin(num='6',name='-',func=pin_types.INPUT,unit=2),
            Pin(num='7',name='~',func=pin_types.OPENCOLL,unit=2),
            Pin(num='4',name='V-',func=pin_types.PWRIN,unit=3),
            Pin(num='8',name='V+',func=pin_types.PWRIN,unit=3)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['1', '2', '3']},{'label': 'uB', 'num': 2, 'pin_nums': ['5', '6', '7']},{'label': 'uC', 'num': 3, 'pin_nums': ['4', '8']}] }),
        Part(**{ 'name':'LM311', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LM311'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'cmp open collector', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/lm311.pdf', 'search_text':'/usr/share/kicad/symbols/Comparator.kicad_sym\nLM311\n\ncmp open collector', 'pins':[
            Pin(num='1',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='+',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='-',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='V-',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='BAL',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='STRB',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='~',func=pin_types.OPENCOLL,unit=1),
            Pin(num='8',name='V+',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LM319', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LM319'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'cmp open collector', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/lm319-n.pdf', 'search_text':'/usr/share/kicad/symbols/Comparator.kicad_sym\nLM319\n\ncmp open collector', 'pins':[
            Pin(num='1',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='12',name='~',func=pin_types.OPENCOLL,unit=1),
            Pin(num='2',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='3',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='+',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='-',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='-',func=pin_types.INPUT,unit=2),
            Pin(num='13',name='NC',func=pin_types.NOCONNECT,unit=2),
            Pin(num='14',name='NC',func=pin_types.NOCONNECT,unit=2),
            Pin(num='7',name='~',func=pin_types.OPENCOLL,unit=2),
            Pin(num='8',name='GND',func=pin_types.PASSIVE,unit=2),
            Pin(num='9',name='+',func=pin_types.INPUT,unit=2),
            Pin(num='11',name='V+',func=pin_types.PWRIN,unit=3),
            Pin(num='6',name='V-',func=pin_types.PWRIN,unit=3)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['5', '3', '2', '12', '1', '4']},{'label': 'uB', 'num': 2, 'pin_nums': ['7', '10', '8', '14', '9', '13']},{'label': 'uC', 'num': 3, 'pin_nums': ['6', '11']}] }),
        Part(**{ 'name':'LM319H', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LM319H'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_THT:TO-100-10'], 'footprint':'Package_TO_SOT_THT:TO-100-10', 'keywords':'cmp open collector', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/lm319-n.pdf', 'search_text':'/usr/share/kicad/symbols/Comparator.kicad_sym\nLM319H\n\ncmp open collector', 'pins':[
            Pin(num='1',name='~',func=pin_types.OPENCOLL,unit=1),
            Pin(num='2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='+',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='-',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='~',func=pin_types.OPENCOLL,unit=2),
            Pin(num='7',name='GND',func=pin_types.PASSIVE,unit=2),
            Pin(num='8',name='+',func=pin_types.INPUT,unit=2),
            Pin(num='9',name='-',func=pin_types.INPUT,unit=2),
            Pin(num='10',name='V+',func=pin_types.PWRIN,unit=3),
            Pin(num='5',name='V-',func=pin_types.PWRIN,unit=3)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['1', '3', '2', '4']},{'label': 'uB', 'num': 2, 'pin_nums': ['9', '8', '6', '7']},{'label': 'uC', 'num': 3, 'pin_nums': ['10', '5']}] }),
        Part(**{ 'name':'LM339', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LM339'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'cmp open collector', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/lm139.pdf', 'search_text':'/usr/share/kicad/symbols/Comparator.kicad_sym\nLM339\n\ncmp open collector', 'pins':[
            Pin(num='2',name='~',func=pin_types.OPENCOLL,unit=1),
            Pin(num='4',name='-',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='+',func=pin_types.INPUT,unit=1),
            Pin(num='1',name='~',func=pin_types.OPENCOLL,unit=2),
            Pin(num='6',name='-',func=pin_types.INPUT,unit=2),
            Pin(num='7',name='+',func=pin_types.INPUT,unit=2),
            Pin(num='10',name='-',func=pin_types.INPUT,unit=3),
            Pin(num='11',name='+',func=pin_types.INPUT,unit=3),
            Pin(num='13',name='~',func=pin_types.OPENCOLL,unit=3),
            Pin(num='14',name='~',func=pin_types.OPENCOLL,unit=4),
            Pin(num='8',name='-',func=pin_types.INPUT,unit=4),
            Pin(num='9',name='+',func=pin_types.INPUT,unit=4),
            Pin(num='12',name='V-',func=pin_types.PWRIN,unit=5),
            Pin(num='3',name='V+',func=pin_types.PWRIN,unit=5)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['2', '4', '5']},{'label': 'uB', 'num': 2, 'pin_nums': ['1', '6', '7']},{'label': 'uC', 'num': 3, 'pin_nums': ['13', '11', '10']},{'label': 'uD', 'num': 4, 'pin_nums': ['14', '9', '8']},{'label': 'uE', 'num': 5, 'pin_nums': ['3', '12']}] }),
        Part(**{ 'name':'LM397', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LM397'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:SOT-23-5'], 'footprint':'Package_TO_SOT_SMD:SOT-23-5', 'keywords':'single comparator', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/lm397.pdf', 'search_text':'/usr/share/kicad/symbols/Comparator.kicad_sym\nLM397\n\nsingle comparator', 'pins':[
            Pin(num='1',name='-',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='V-',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='+',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='~',func=pin_types.OPENCOLL,unit=1),
            Pin(num='5',name='V+',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LMH7324', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LMH7324'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:WQFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm'], 'footprint':'Package_DFN_QFN:WQFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm', 'keywords':'cmp push-pull complementary', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/lmh7324.pdf', 'search_text':'/usr/share/kicad/symbols/Comparator.kicad_sym\nLMH7324\n\ncmp push-pull complementary', 'pins':[
            Pin(num='1',name='VCCO',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='~{Q}',func=pin_types.OUTPUT,unit=1),
            Pin(num='29',name='VEE',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Q',func=pin_types.OUTPUT,unit=1),
            Pin(num='30',name='+',func=pin_types.INPUT,unit=1),
            Pin(num='31',name='-',func=pin_types.INPUT,unit=1),
            Pin(num='32',name='VCCI',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='VEE',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='-',func=pin_types.INPUT,unit=2),
            Pin(num='11',name='+',func=pin_types.INPUT,unit=2),
            Pin(num='12',name='VEE',func=pin_types.PASSIVE,unit=2),
            Pin(num='5',name='VEE',func=pin_types.PWRIN,unit=2),
            Pin(num='6',name='Q',func=pin_types.OUTPUT,unit=2),
            Pin(num='7',name='~{Q}',func=pin_types.OUTPUT,unit=2),
            Pin(num='8',name='VCCO',func=pin_types.PWRIN,unit=2),
            Pin(num='9',name='VCCI',func=pin_types.PWRIN,unit=2),
            Pin(num='13',name='VEE',func=pin_types.PWRIN,unit=3),
            Pin(num='14',name='+',func=pin_types.INPUT,unit=3),
            Pin(num='15',name='-',func=pin_types.INPUT,unit=3),
            Pin(num='16',name='VCCI',func=pin_types.PWRIN,unit=3),
            Pin(num='17',name='VCCO',func=pin_types.PWRIN,unit=3),
            Pin(num='18',name='~{Q}',func=pin_types.OUTPUT,unit=3),
            Pin(num='19',name='Q',func=pin_types.OUTPUT,unit=3),
            Pin(num='20',name='VEE',func=pin_types.PASSIVE,unit=3),
            Pin(num='21',name='VEE',func=pin_types.PWRIN,unit=4),
            Pin(num='22',name='Q',func=pin_types.OUTPUT,unit=4),
            Pin(num='23',name='~{Q}',func=pin_types.OUTPUT,unit=4),
            Pin(num='24',name='VCCO',func=pin_types.PWRIN,unit=4),
            Pin(num='25',name='VCCI',func=pin_types.PWRIN,unit=4),
            Pin(num='26',name='-',func=pin_types.INPUT,unit=4),
            Pin(num='27',name='+',func=pin_types.INPUT,unit=4),
            Pin(num='28',name='VEE',func=pin_types.PASSIVE,unit=4),
            Pin(num='33',name='VEE/EP',func=pin_types.PWRIN,unit=5)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['31', '1', '2', '3', '29', '32', '30', '4']},{'label': 'uB', 'num': 2, 'pin_nums': ['12', '9', '7', '10', '5', '8', '11', '6']},{'label': 'uC', 'num': 3, 'pin_nums': ['16', '18', '14', '20', '15', '13', '17', '19']},{'label': 'uD', 'num': 4, 'pin_nums': ['22', '26', '24', '28', '21', '23', '25', '27']},{'label': 'uE', 'num': 5, 'pin_nums': ['33']}] }),
        Part(**{ 'name':'LMV331', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LMV331'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'single comparator', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/lmv331.pdf', 'search_text':'/usr/share/kicad/symbols/Comparator.kicad_sym\nLMV331\n\nsingle comparator', 'pins':[
            Pin(num='1',name='+',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='V-',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='-',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='~',func=pin_types.OPENCOLL,unit=1),
            Pin(num='5',name='V+',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LMV393', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LMV393'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'cmp open collector', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/lmv331.pdf', 'search_text':'/usr/share/kicad/symbols/Comparator.kicad_sym\nLMV393\n\ncmp open collector', 'pins':[
            Pin(num='1',name='~',func=pin_types.OPENCOLL,unit=1),
            Pin(num='2',name='-',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='+',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='+',func=pin_types.INPUT,unit=2),
            Pin(num='6',name='-',func=pin_types.INPUT,unit=2),
            Pin(num='7',name='~',func=pin_types.OPENCOLL,unit=2),
            Pin(num='4',name='V-',func=pin_types.PWRIN,unit=3),
            Pin(num='8',name='V+',func=pin_types.PWRIN,unit=3)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['3', '2', '1']},{'label': 'uB', 'num': 2, 'pin_nums': ['5', '6', '7']},{'label': 'uC', 'num': 3, 'pin_nums': ['8', '4']}] }),
        Part(**{ 'name':'LMV7271', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LMV7271'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'cmp', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/lmv7271.pdf', 'search_text':'/usr/share/kicad/symbols/Comparator.kicad_sym\nLMV7271\n\ncmp', 'pins':[
            Pin(num='1',name='+',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='V-',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='-',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='V+',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LMV7272', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LMV7272'}), 'ref_prefix':'U', 'fplist':['Package_BGA:Texas_DSBGA-8_1.5195x1.5195mm_Layout3x3_P0.5mm'], 'footprint':'Package_BGA:Texas_DSBGA-8_1.5195x1.5195mm_Layout3x3_P0.5mm', 'keywords':'cmp', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/lmv7272.pdf', 'search_text':'/usr/share/kicad/symbols/Comparator.kicad_sym\nLMV7272\n\ncmp', 'pins':[
            Pin(num='A1',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='B1',name='-',func=pin_types.INPUT,unit=1),
            Pin(num='C1',name='+',func=pin_types.INPUT,unit=1),
            Pin(num='A3',name='~',func=pin_types.OUTPUT,unit=2),
            Pin(num='B3',name='-',func=pin_types.INPUT,unit=2),
            Pin(num='C3',name='+',func=pin_types.INPUT,unit=2),
            Pin(num='A2',name='V+',func=pin_types.PWRIN,unit=3),
            Pin(num='C2',name='V-',func=pin_types.PWRIN,unit=3)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['C1', 'B1', 'A1']},{'label': 'uB', 'num': 2, 'pin_nums': ['C3', 'A3', 'B3']},{'label': 'uC', 'num': 3, 'pin_nums': ['A2', 'C2']}] }),
        Part(**{ 'name':'LT1016', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LT1016'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'cmp push-pull complementary latch', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/lt1016.pdf', 'search_text':'/usr/share/kicad/symbols/Comparator.kicad_sym\nLT1016\n\ncmp push-pull complementary latch', 'pins':[
            Pin(num='1',name='V+',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='+',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='-',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='V-',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='LATCH',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='Q',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='~{Q}',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LT1711xMS8', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LT1711xMS8'}), 'ref_prefix':'U', 'fplist':['Package_SO:MSOP-8_3x3mm_P0.65mm'], 'footprint':'Package_SO:MSOP-8_3x3mm_P0.65mm', 'keywords':'cmp latch push-pull complementary', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/171112f.pdf', 'search_text':'/usr/share/kicad/symbols/Comparator.kicad_sym\nLT1711xMS8\n\ncmp latch push-pull complementary', 'pins':[
            Pin(num='1',name='V+',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='+',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='-',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='V-',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='LATCH',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='Q',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='~{Q}',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LTC6752xMS8-2', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LTC6752xMS8-2'}), 'ref_prefix':'U', 'fplist':['Package_SO:MSOP-8_3x3mm_P0.65mm'], 'footprint':'Package_SO:MSOP-8_3x3mm_P0.65mm', 'keywords':'single comparator high speed cmos', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/6752fc.pdf', 'search_text':'/usr/share/kicad/symbols/Comparator.kicad_sym\nLTC6752xMS8-2\n\nsingle comparator high speed cmos', 'pins':[
            Pin(num='1',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='+',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='-',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='~{SHDN}',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='~{LE}',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='VEE',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='VDD',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LTC6752xS5', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LTC6752xS5'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:TSOT-23-5'], 'footprint':'Package_TO_SOT_SMD:TSOT-23-5', 'keywords':'single comparator high speed cmos', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/6752fc.pdf', 'search_text':'/usr/share/kicad/symbols/Comparator.kicad_sym\nLTC6752xS5\n\nsingle comparator high speed cmos', 'pins':[
            Pin(num='1',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='VEE',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='+',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='-',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LTC6752xSC6-1', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LTC6752xSC6-1'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:SOT-363_SC-70-6'], 'footprint':'Package_TO_SOT_SMD:SOT-363_SC-70-6', 'keywords':'single comparator high speed cmos', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/6752fc.pdf', 'search_text':'/usr/share/kicad/symbols/Comparator.kicad_sym\nLTC6752xSC6-1\n\nsingle comparator high speed cmos', 'pins':[
            Pin(num='1',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='VEE',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='+',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='-',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='~{LE}',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LTC6752xSC6-4', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LTC6752xSC6-4'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:SOT-363_SC-70-6'], 'footprint':'Package_TO_SOT_SMD:SOT-363_SC-70-6', 'keywords':'single comparator high speed cmos', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/6752fc.pdf', 'search_text':'/usr/share/kicad/symbols/Comparator.kicad_sym\nLTC6752xSC6-4\n\nsingle comparator high speed cmos', 'pins':[
            Pin(num='1',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='VEE',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='+',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='-',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LTC6752xUD-3', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LTC6752xUD-3'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-12-1EP_3x3mm_P0.5mm_EP1.65x1.65mm'], 'footprint':'Package_DFN_QFN:QFN-12-1EP_3x3mm_P0.5mm_EP1.65x1.65mm', 'keywords':'single comparator high speed cmos', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/6752fc.pdf', 'search_text':'/usr/share/kicad/symbols/Comparator.kicad_sym\nLTC6752xUD-3\n\nsingle comparator high speed cmos', 'pins':[
            Pin(num='1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='~{Q}',func=pin_types.OUTPUT,unit=1),
            Pin(num='11',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='12',name='Q',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='VEE',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='VEE',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='+',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='6',name='-',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='~{SHDN}',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='~{LE}',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='VEE',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LTC6754xSC6', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LTC6754xSC6'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:SOT-363_SC-70-6'], 'footprint':'Package_TO_SOT_SMD:SOT-363_SC-70-6', 'keywords':'cmp r2r rtr push-pull complementary', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/6754f.pdf', 'search_text':'/usr/share/kicad/symbols/Comparator.kicad_sym\nLTC6754xSC6\n\ncmp r2r rtr push-pull complementary', 'pins':[
            Pin(num='1',name='Q',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='VEE',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='+',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='-',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='~{Q}',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LTC6754xUD', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LTC6754xUD'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-12-1EP_3x3mm_P0.5mm_EP1.65x1.65mm'], 'footprint':'Package_DFN_QFN:QFN-12-1EP_3x3mm_P0.5mm_EP1.65x1.65mm', 'keywords':'cmp r2r rtr push-pull complementary', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/6754f.pdf', 'search_text':'/usr/share/kicad/symbols/Comparator.kicad_sym\nLTC6754xUD\n\ncmp r2r rtr push-pull complementary', 'pins':[
            Pin(num='1',name='VCCO',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='~{Q}',func=pin_types.OUTPUT,unit=1),
            Pin(num='11',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='12',name='Q',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='VEE',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='VCCI',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='VEE',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='+',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='6',name='-',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='~{SHDN}',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='~{LE}',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='VEE',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MAX941xPA', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MAX941xPA'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-8_W7.62mm'], 'footprint':'Package_DIP:DIP-8_W7.62mm', 'keywords':'single comparator', 'description':'', 'datasheet':'https://datasheets.maximintegrated.com/en/ds/MAX941-MAX944.pdf', 'search_text':'/usr/share/kicad/symbols/Comparator.kicad_sym\nMAX941xPA\n\nsingle comparator', 'pins':[
            Pin(num='1',name='V+',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='+',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='-',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='~{SHDN}',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='~{LATCH}',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='V-',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MAX941xSA', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MAX941xSA'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-8_3.9x4.9mm_P1.27mm'], 'footprint':'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'keywords':'single comparator', 'description':'', 'datasheet':'https://datasheets.maximintegrated.com/en/ds/MAX941-MAX944.pdf', 'search_text':'/usr/share/kicad/symbols/Comparator.kicad_sym\nMAX941xSA\n\nsingle comparator', 'pins':[
            Pin(num='1',name='V+',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='+',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='-',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='~{SHDN}',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='~{LATCH}',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='V-',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MAX941xUA', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MAX941xUA'}), 'ref_prefix':'U', 'fplist':['Package_SO:MSOP-8_3x3mm_P0.65mm'], 'footprint':'Package_SO:MSOP-8_3x3mm_P0.65mm', 'keywords':'single comparator', 'description':'', 'datasheet':'https://datasheets.maximintegrated.com/en/ds/MAX941-MAX944.pdf', 'search_text':'/usr/share/kicad/symbols/Comparator.kicad_sym\nMAX941xUA\n\nsingle comparator', 'pins':[
            Pin(num='1',name='V+',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='+',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='-',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='~{SHDN}',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='~{LATCH}',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='V-',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MCP6561-OT', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MCP6561-OT'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:SOT-23-5'], 'footprint':'Package_TO_SOT_SMD:SOT-23-5', 'keywords':'cmp', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/MCP6561-1R-1U-2-4-1.8V-Low-Power-Push-Pull-Output-Comparator-DS20002139E.pdf', 'search_text':'/usr/share/kicad/symbols/Comparator.kicad_sym\nMCP6561-OT\n\ncmp', 'pins':[
            Pin(num='2',name='V-',func=pin_types.PWRIN),
            Pin(num='5',name='V+',func=pin_types.PWRIN),
            Pin(num='1',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='+',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='-',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MCP6561R', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MCP6561R'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:SOT-23-5'], 'footprint':'Package_TO_SOT_SMD:SOT-23-5', 'keywords':'cmp', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/MCP6561-1R-1U-2-4-1.8V-Low-Power-Push-Pull-Output-Comparator-DS20002139E.pdf', 'search_text':'/usr/share/kicad/symbols/Comparator.kicad_sym\nMCP6561R\n\ncmp', 'pins':[
            Pin(num='2',name='V+',func=pin_types.PWRIN),
            Pin(num='5',name='V-',func=pin_types.PWRIN),
            Pin(num='1',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='+',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='-',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MCP6561U', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MCP6561U'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:SOT-23-5'], 'footprint':'Package_TO_SOT_SMD:SOT-23-5', 'keywords':'cmp', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/MCP6561-1R-1U-2-4-1.8V-Low-Power-Push-Pull-Output-Comparator-DS20002139E.pdf', 'search_text':'/usr/share/kicad/symbols/Comparator.kicad_sym\nMCP6561U\n\ncmp', 'pins':[
            Pin(num='2',name='V-',func=pin_types.PWRIN),
            Pin(num='5',name='V+',func=pin_types.PWRIN),
            Pin(num='1',name='+',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='-',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='~',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MCP6561x-LT', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MCP6561x-LT'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:SOT-353_SC-70-5'], 'footprint':'Package_TO_SOT_SMD:SOT-353_SC-70-5', 'keywords':'cmp', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/MCP6561-1R-1U-2-4-1.8V-Low-Power-Push-Pull-Output-Comparator-DS20002139E.pdf', 'search_text':'/usr/share/kicad/symbols/Comparator.kicad_sym\nMCP6561x-LT\n\ncmp', 'pins':[
            Pin(num='2',name='V-',func=pin_types.PWRIN),
            Pin(num='5',name='V+',func=pin_types.PWRIN),
            Pin(num='1',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='+',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='-',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MCP6562', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MCP6562'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'cmp', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/MCP6561-1R-1U-2-4-1.8V-Low-Power-Push-Pull-Output-Comparator-DS20002139E.pdf', 'search_text':'/usr/share/kicad/symbols/Comparator.kicad_sym\nMCP6562\n\ncmp', 'pins':[
            Pin(num='1',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='-',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='+',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='+',func=pin_types.INPUT,unit=2),
            Pin(num='6',name='-',func=pin_types.INPUT,unit=2),
            Pin(num='7',name='~',func=pin_types.OUTPUT,unit=2),
            Pin(num='4',name='V-',func=pin_types.PWRIN,unit=3),
            Pin(num='8',name='V+',func=pin_types.PWRIN,unit=3)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['1', '2', '3']},{'label': 'uB', 'num': 2, 'pin_nums': ['5', '6', '7']},{'label': 'uC', 'num': 3, 'pin_nums': ['4', '8']}] }),
        Part(**{ 'name':'MCP6566', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MCP6566'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'cmp collector', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/MCP6566-6R-6U-7-9-1.8V-Low-Power-Open-Drain-Output-Comparator-DS20002143G.pdf', 'search_text':'/usr/share/kicad/symbols/Comparator.kicad_sym\nMCP6566\n\ncmp collector', 'pins':[
            Pin(num='2',name='V-',func=pin_types.PWRIN),
            Pin(num='5',name='V+',func=pin_types.PWRIN),
            Pin(num='1',name='~',func=pin_types.OPENCOLL,unit=1),
            Pin(num='3',name='+',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='-',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MCP6566R', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MCP6566R'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:SOT-23-5'], 'footprint':'Package_TO_SOT_SMD:SOT-23-5', 'keywords':'cmp collector', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/MCP6566-6R-6U-7-9-1.8V-Low-Power-Open-Drain-Output-Comparator-DS20002143G.pdf', 'search_text':'/usr/share/kicad/symbols/Comparator.kicad_sym\nMCP6566R\n\ncmp collector', 'pins':[
            Pin(num='2',name='V+',func=pin_types.PWRIN),
            Pin(num='5',name='V-',func=pin_types.PWRIN),
            Pin(num='1',name='~',func=pin_types.OPENCOLL,unit=1),
            Pin(num='3',name='+',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='-',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MCP6566U', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MCP6566U'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:SOT-23-5'], 'footprint':'Package_TO_SOT_SMD:SOT-23-5', 'keywords':'cmp collector', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/MCP6566-6R-6U-7-9-1.8V-Low-Power-Open-Drain-Output-Comparator-DS20002143G.pdf', 'search_text':'/usr/share/kicad/symbols/Comparator.kicad_sym\nMCP6566U\n\ncmp collector', 'pins':[
            Pin(num='2',name='V-',func=pin_types.PWRIN),
            Pin(num='5',name='V+',func=pin_types.PWRIN),
            Pin(num='1',name='+',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='-',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='~',func=pin_types.OPENCOLL,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MCP6567', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MCP6567'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'cmp collector', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/MCP6566-6R-6U-7-9-1.8V-Low-Power-Open-Drain-Output-Comparator-DS20002143G.pdf', 'search_text':'/usr/share/kicad/symbols/Comparator.kicad_sym\nMCP6567\n\ncmp collector', 'pins':[
            Pin(num='1',name='~',func=pin_types.OPENCOLL,unit=1),
            Pin(num='2',name='-',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='+',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='+',func=pin_types.INPUT,unit=2),
            Pin(num='6',name='-',func=pin_types.INPUT,unit=2),
            Pin(num='7',name='~',func=pin_types.OPENCOLL,unit=2),
            Pin(num='4',name='V-',func=pin_types.PWRIN,unit=3),
            Pin(num='8',name='V+',func=pin_types.PWRIN,unit=3)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['2', '3', '1']},{'label': 'uB', 'num': 2, 'pin_nums': ['6', '5', '7']},{'label': 'uC', 'num': 3, 'pin_nums': ['4', '8']}] }),
        Part(**{ 'name':'MCP6569', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MCP6569'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'cmp collector', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/MCP6566-6R-6U-7-9-1.8V-Low-Power-Open-Drain-Output-Comparator-DS20002143G.pdf', 'search_text':'/usr/share/kicad/symbols/Comparator.kicad_sym\nMCP6569\n\ncmp collector', 'pins':[
            Pin(num='1',name='~',func=pin_types.OPENCOLL,unit=1),
            Pin(num='2',name='-',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='+',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='+',func=pin_types.INPUT,unit=2),
            Pin(num='6',name='-',func=pin_types.INPUT,unit=2),
            Pin(num='7',name='~',func=pin_types.OPENCOLL,unit=2),
            Pin(num='10',name='+',func=pin_types.INPUT,unit=3),
            Pin(num='8',name='~',func=pin_types.OPENCOLL,unit=3),
            Pin(num='9',name='-',func=pin_types.INPUT,unit=3),
            Pin(num='12',name='+',func=pin_types.INPUT,unit=4),
            Pin(num='13',name='-',func=pin_types.INPUT,unit=4),
            Pin(num='14',name='~',func=pin_types.OPENCOLL,unit=4),
            Pin(num='11',name='V-',func=pin_types.PWRIN,unit=5),
            Pin(num='4',name='V+',func=pin_types.PWRIN,unit=5)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['3', '1', '2']},{'label': 'uB', 'num': 2, 'pin_nums': ['7', '5', '6']},{'label': 'uC', 'num': 3, 'pin_nums': ['10', '8', '9']},{'label': 'uD', 'num': 4, 'pin_nums': ['12', '14', '13']},{'label': 'uE', 'num': 5, 'pin_nums': ['11', '4']}] }),
        Part(**{ 'name':'MCP65R41', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MCP65R41'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:SOT-23-6'], 'footprint':'Package_TO_SOT_SMD:SOT-23-6', 'keywords':'cmp reference', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/22269B.pdf', 'search_text':'/usr/share/kicad/symbols/Comparator.kicad_sym\nMCP65R41\n\ncmp reference', 'pins':[
            Pin(num='1',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='V-',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='+',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='-',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='Vref',func=pin_types.PWROUT,unit=1),
            Pin(num='6',name='V+',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MCP65R46', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MCP65R46'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:SOT-23-6'], 'footprint':'Package_TO_SOT_SMD:SOT-23-6', 'keywords':'cmp reference open collector drain', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/22269B.pdf', 'search_text':'/usr/share/kicad/symbols/Comparator.kicad_sym\nMCP65R46\n\ncmp reference open collector drain', 'pins':[
            Pin(num='1',name='~',func=pin_types.OPENCOLL,unit=1),
            Pin(num='2',name='V-',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='+',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='-',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='Vref',func=pin_types.PWROUT,unit=1),
            Pin(num='6',name='V+',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MIC845H', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MIC845H'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:SOT-353_SC-70-5'], 'footprint':'Package_TO_SOT_SMD:SOT-353_SC-70-5', 'keywords':'single cmp', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/mic845.pdf', 'search_text':'/usr/share/kicad/symbols/Comparator.kicad_sym\nMIC845H\n\nsingle cmp', 'pins':[
            Pin(num='1',name='NIC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='+',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='V+',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MIC845N', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MIC845N'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:SOT-353_SC-70-5'], 'footprint':'Package_TO_SOT_SMD:SOT-353_SC-70-5', 'keywords':'single cmp collector', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/mic845.pdf', 'search_text':'/usr/share/kicad/symbols/Comparator.kicad_sym\nMIC845N\n\nsingle cmp collector', 'pins':[
            Pin(num='1',name='NIC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='+',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='~',func=pin_types.OPENCOLL,unit=1),
            Pin(num='5',name='V+',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TL3116', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TL3116'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'cmp push-pull complementary', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/tl3116.pdf', 'search_text':'/usr/share/kicad/symbols/Comparator.kicad_sym\nTL3116\n\ncmp push-pull complementary', 'pins':[
            Pin(num='1',name='V+',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='+',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='-',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='V-',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='LATCH',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='Q',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='~{Q}',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TLV3501AID', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TLV3501AID'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-8_3.9x4.9mm_P1.27mm'], 'footprint':'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'keywords':'single comparator high speed cmos', 'description':'', 'datasheet':'https://www.ti.com/lit/ds/symlink/tlv3501.pdf', 'search_text':'/usr/share/kicad/symbols/Comparator.kicad_sym\nTLV3501AID\n\nsingle comparator high speed cmos', 'pins':[
            Pin(num='1',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='2',name='-',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='+',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='V-',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='6',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='V+',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='SHDN',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TLV3501AIDBV', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TLV3501AIDBV'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:SOT-23-6'], 'footprint':'Package_TO_SOT_SMD:SOT-23-6', 'keywords':'single comparator high speed cmos', 'description':'', 'datasheet':'https://www.ti.com/lit/ds/symlink/tlv3501.pdf', 'search_text':'/usr/share/kicad/symbols/Comparator.kicad_sym\nTLV3501AIDBV\n\nsingle comparator high speed cmos', 'pins':[
            Pin(num='1',name='-',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='V-',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='+',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='V+',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='SHDN',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ADCMP354', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ADCMP354'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:Analog_KS-4', 'Package_TO_SOT_SMD:Analog_KS-4'], 'footprint':'Package_TO_SOT_SMD:Analog_KS-4', 'keywords':'cmp collector', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/ADCMP350_354_356.pdf', 'search_text':'/usr/share/kicad/symbols/Comparator.kicad_sym\nADCMP354\n\ncmp collector', 'pins':[
            Pin(num='1',name='VIN',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='~',func=pin_types.OPENCOLL,unit=1),
            Pin(num='4',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LM393', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LM393'}), 'ref_prefix':'U', 'fplist':['', ''], 'footprint':'', 'keywords':'cmp open collector', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/lm393.pdf', 'search_text':'/usr/share/kicad/symbols/Comparator.kicad_sym\nLM393\n\ncmp open collector', 'pins':[
            Pin(num='1',name='~',func=pin_types.OPENCOLL,unit=1),
            Pin(num='2',name='-',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='+',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='+',func=pin_types.INPUT,unit=2),
            Pin(num='6',name='-',func=pin_types.INPUT,unit=2),
            Pin(num='7',name='~',func=pin_types.OPENCOLL,unit=2),
            Pin(num='4',name='V-',func=pin_types.PWRIN,unit=3),
            Pin(num='8',name='V+',func=pin_types.PWRIN,unit=3)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['2', '3', '1']},{'label': 'uB', 'num': 2, 'pin_nums': ['5', '7', '6']},{'label': 'uC', 'num': 3, 'pin_nums': ['4', '8']}] }),
        Part(**{ 'name':'LMV339', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LMV339'}), 'ref_prefix':'U', 'fplist':['', ''], 'footprint':'', 'keywords':'cmp open collector', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/lmv331.pdf', 'search_text':'/usr/share/kicad/symbols/Comparator.kicad_sym\nLMV339\n\ncmp open collector', 'pins':[
            Pin(num='2',name='~',func=pin_types.OPENCOLL,unit=1),
            Pin(num='4',name='-',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='+',func=pin_types.INPUT,unit=1),
            Pin(num='1',name='~',func=pin_types.OPENCOLL,unit=2),
            Pin(num='6',name='-',func=pin_types.INPUT,unit=2),
            Pin(num='7',name='+',func=pin_types.INPUT,unit=2),
            Pin(num='10',name='-',func=pin_types.INPUT,unit=3),
            Pin(num='11',name='+',func=pin_types.INPUT,unit=3),
            Pin(num='13',name='~',func=pin_types.OPENCOLL,unit=3),
            Pin(num='14',name='~',func=pin_types.OPENCOLL,unit=4),
            Pin(num='8',name='-',func=pin_types.INPUT,unit=4),
            Pin(num='9',name='+',func=pin_types.INPUT,unit=4),
            Pin(num='12',name='V-',func=pin_types.PWRIN,unit=5),
            Pin(num='3',name='V+',func=pin_types.PWRIN,unit=5)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['5', '2', '4']},{'label': 'uB', 'num': 2, 'pin_nums': ['1', '6', '7']},{'label': 'uC', 'num': 3, 'pin_nums': ['11', '13', '10']},{'label': 'uD', 'num': 4, 'pin_nums': ['8', '14', '9']},{'label': 'uE', 'num': 5, 'pin_nums': ['3', '12']}] }),
        Part(**{ 'name':'LMV7219M5', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LMV7219M5'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:SOT-23-5', 'Package_TO_SOT_SMD:SOT-23-5'], 'footprint':'Package_TO_SOT_SMD:SOT-23-5', 'keywords':'cmp', 'description':'', 'datasheet':'https://www.ti.com/lit/ds/symlink/lmv7219.pdf', 'search_text':'/usr/share/kicad/symbols/Comparator.kicad_sym\nLMV7219M5\n\ncmp', 'pins':[
            Pin(num='2',name='V-',func=pin_types.PWRIN),
            Pin(num='5',name='V+',func=pin_types.PWRIN),
            Pin(num='1',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='+',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='-',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LMV7219M7', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LMV7219M7'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:SOT-353_SC-70-5', 'Package_TO_SOT_SMD:SOT-353_SC-70-5'], 'footprint':'Package_TO_SOT_SMD:SOT-353_SC-70-5', 'keywords':'cmp', 'description':'', 'datasheet':'https://www.ti.com/lit/ds/symlink/lmv7219.pdf', 'search_text':'/usr/share/kicad/symbols/Comparator.kicad_sym\nLMV7219M7\n\ncmp', 'pins':[
            Pin(num='2',name='V-',func=pin_types.PWRIN),
            Pin(num='5',name='V+',func=pin_types.PWRIN),
            Pin(num='1',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='+',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='-',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LMV7275', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LMV7275'}), 'ref_prefix':'U', 'fplist':['', ''], 'footprint':'', 'keywords':'cmp', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/lmv7275.pdf', 'search_text':'/usr/share/kicad/symbols/Comparator.kicad_sym\nLMV7275\n\ncmp', 'pins':[
            Pin(num='1',name='+',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='V-',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='-',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='~',func=pin_types.OPENCOLL,unit=1),
            Pin(num='5',name='V+',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LP2901D', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LP2901D'}), 'ref_prefix':'U', 'fplist':['', '', 'Package_SO:SOIC-14_3.9x8.7mm_P1.27mm'], 'footprint':'', 'keywords':'cmp open collector', 'description':'', 'datasheet':'https://www.ti.com/lit/ds/symlink/lp2901.pdf', 'search_text':'/usr/share/kicad/symbols/Comparator.kicad_sym\nLP2901D\n\ncmp open collector', 'pins':[
            Pin(num='2',name='~',func=pin_types.OPENCOLL,unit=1),
            Pin(num='4',name='-',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='+',func=pin_types.INPUT,unit=1),
            Pin(num='1',name='~',func=pin_types.OPENCOLL,unit=2),
            Pin(num='6',name='-',func=pin_types.INPUT,unit=2),
            Pin(num='7',name='+',func=pin_types.INPUT,unit=2),
            Pin(num='10',name='-',func=pin_types.INPUT,unit=3),
            Pin(num='11',name='+',func=pin_types.INPUT,unit=3),
            Pin(num='13',name='~',func=pin_types.OPENCOLL,unit=3),
            Pin(num='14',name='~',func=pin_types.OPENCOLL,unit=4),
            Pin(num='8',name='-',func=pin_types.INPUT,unit=4),
            Pin(num='9',name='+',func=pin_types.INPUT,unit=4),
            Pin(num='12',name='V-',func=pin_types.PWRIN,unit=5),
            Pin(num='3',name='V+',func=pin_types.PWRIN,unit=5)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['5', '2', '4']},{'label': 'uB', 'num': 2, 'pin_nums': ['6', '7', '1']},{'label': 'uC', 'num': 3, 'pin_nums': ['13', '10', '11']},{'label': 'uD', 'num': 4, 'pin_nums': ['14', '9', '8']},{'label': 'uE', 'num': 5, 'pin_nums': ['12', '3']}] }),
        Part(**{ 'name':'LT1011', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LT1011'}), 'ref_prefix':'U', 'fplist':['', ''], 'footprint':'', 'keywords':'cmp open collector', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/lt1011.pdf', 'search_text':'/usr/share/kicad/symbols/Comparator.kicad_sym\nLT1011\n\ncmp open collector', 'pins':[
            Pin(num='1',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='+',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='-',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='V-',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='BAL',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='STRB',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='~',func=pin_types.OPENCOLL,unit=1),
            Pin(num='8',name='V+',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LT1116', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LT1116'}), 'ref_prefix':'U', 'fplist':['', ''], 'footprint':'', 'keywords':'cmp push-pull complementary latch', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/1116fc.pdf', 'search_text':'/usr/share/kicad/symbols/Comparator.kicad_sym\nLT1116\n\ncmp push-pull complementary latch', 'pins':[
            Pin(num='1',name='V+',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='+',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='-',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='V-',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='LATCH',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='Q',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='~{Q}',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MAX9031AU', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MAX9031AU'}), 'ref_prefix':'U', 'fplist':['', 'Package_TO_SOT_SMD:SOT-23-5'], 'footprint':'', 'keywords':'rail-rail', 'description':'', 'datasheet':'https://datasheets.maximintegrated.com/en/ds/MAX9030-MAX9034.pdf', 'search_text':'/usr/share/kicad/symbols/Comparator.kicad_sym\nMAX9031AU\n\nrail-rail', 'pins':[
            Pin(num='1',name='+',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='V-',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='-',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='V+',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MAX9031AX', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MAX9031AX'}), 'ref_prefix':'U', 'fplist':['', 'Package_TO_SOT_SMD:SOT-23-5', 'Package_TO_SOT_SMD:SOT-353_SC-70-5'], 'footprint':'', 'keywords':'rail-rail', 'description':'', 'datasheet':'https://datasheets.maximintegrated.com/en/ds/MAX9030-MAX9034.pdf', 'search_text':'/usr/share/kicad/symbols/Comparator.kicad_sym\nMAX9031AX\n\nrail-rail', 'pins':[
            Pin(num='1',name='+',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='V-',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='-',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='V+',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MIC845L', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MIC845L'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:SOT-353_SC-70-5', 'Package_TO_SOT_SMD:SOT-353_SC-70-5'], 'footprint':'Package_TO_SOT_SMD:SOT-353_SC-70-5', 'keywords':'single cmp', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/mic845.pdf', 'search_text':'/usr/share/kicad/symbols/Comparator.kicad_sym\nMIC845L\n\nsingle cmp', 'pins':[
            Pin(num='1',name='NIC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='+',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='V+',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TL331', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TL331'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:SOT-23-5', 'Package_TO_SOT_SMD:SOT-23-5'], 'footprint':'Package_TO_SOT_SMD:SOT-23-5', 'keywords':'single comparator', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/tl331.pdf', 'search_text':'/usr/share/kicad/symbols/Comparator.kicad_sym\nTL331\n\nsingle comparator', 'pins':[
            Pin(num='1',name='-',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='V-',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='+',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='~',func=pin_types.OPENCOLL,unit=1),
            Pin(num='5',name='V+',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TLV7031DBV', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TLV7031DBV'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:SOT-23-5', 'Package_TO_SOT_SMD:SOT-23-5', 'Package_TO_SOT_SMD:SOT-23-5'], 'footprint':'Package_TO_SOT_SMD:SOT-23-5', 'keywords':'cmp', 'description':'', 'datasheet':'https://www.ti.com/lit/ds/symlink/tlv7031.pdf', 'search_text':'/usr/share/kicad/symbols/Comparator.kicad_sym\nTLV7031DBV\n\ncmp', 'pins':[
            Pin(num='2',name='V-',func=pin_types.PWRIN),
            Pin(num='5',name='V+',func=pin_types.PWRIN),
            Pin(num='1',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='+',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='-',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TLV7041DBV', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TLV7041DBV'}), 'ref_prefix':'U', 'fplist':['', ''], 'footprint':'', 'keywords':'cmp collector', 'description':'', 'datasheet':'https://www.ti.com/lit/ds/symlink/tlv7041.pdf', 'search_text':'/usr/share/kicad/symbols/Comparator.kicad_sym\nTLV7041DBV\n\ncmp collector', 'pins':[
            Pin(num='2',name='V-',func=pin_types.PWRIN),
            Pin(num='5',name='V+',func=pin_types.PWRIN),
            Pin(num='1',name='~',func=pin_types.OPENCOLL,unit=1),
            Pin(num='3',name='+',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='-',func=pin_types.INPUT,unit=1)], 'unit_defs':[] })])